diff --git a/game/client/src/main/java/net/minecraft/client/gui/ScreenMainMenu.java b/game/client/src/main/java/net/minecraft/client/gui/ScreenMainMenu.java
index 11af275aa..76abaefb3 100644
--- a/game/client/src/main/java/net/minecraft/client/gui/ScreenMainMenu.java
+++ b/game/client/src/main/java/net/minecraft/client/gui/ScreenMainMenu.java
@@ -58,11 +58,13 @@ public class ScreenMainMenu extends Screen
     private String splashText = "missingno";
     private ButtonElement multiplayerButton;
     private LogoBlock[][] logoBlocks;
+    private Snowflake[] snowflakes = new Snowflake[50];
     private int logoClickCounter = 0;
     private int indexToDraw = 0;
     private int codeProgress = 0;
     private boolean showBuildTime = false;
     private String buildTimeString = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date(Version.BUILD_TIME));
+    private int snowfallTimer = 0;
     
     static {
     	loadLogo();
@@ -127,6 +129,10 @@ public class ScreenMainMenu extends Screen
     {
         I18n i18n = I18n.getInstance();
 
+        for(int i = 0; i < snowflakes.length; i++){
+            snowflakes[i] = new Snowflake(rand.nextInt(width), rand.nextInt(height),1 + rand.nextInt(4), height);
+        }
+
         if (Holidays.ANNIVERSARY_JONKADELIC.isActive())
         {
             splashText = i18n.translateKey("gui.main_menu.label.splash.jonkadelic_birthday");
@@ -271,6 +277,10 @@ public class ScreenMainMenu extends Screen
     @Override
     public void tick()
     {
+        for (Snowflake snowflake : snowflakes) {
+            snowflake.updateEffects();
+        }
+
         if(this.logoBlocks != null)
         {
             for (LogoBlock[] logoBlock : this.logoBlocks) {
@@ -332,6 +342,17 @@ public class ScreenMainMenu extends Screen
         {
             drawLogo(partialTick);
         }
+
+        mc.textureManager.loadTexture("/assets/minecraft/textures/gui/title/snowflake.png").bind();
+        GL11.glColor4f(1.0F, 1.0F, 1.0F, 1.0F);
+
+        // Render snow particles on title screen on Christmas
+        if(Holidays.getCurrentThemedHoliday() == Holidays.XMAS) {
+            for (Snowflake snowflake : snowflakes) {
+                drawTexturedModalRectDouble(snowflake.flakeX, snowflake.flakeY, 0, 4 * snowflake.texIndex, 4, 4, 1d / 4, 1d / 16);
+            }
+        }
+
         GL11.glPushMatrix();
         GL11.glTranslatef(width / 2 + 140, 80F, 0.0F);
         GL11.glRotatef(-20F, 0.0F, 0.0F, 1.0F);
@@ -489,6 +510,36 @@ public class ScreenMainMenu extends Screen
             LOGGER.error("Exception while loading retro logo!", e);
 		}
     }
+
+    static class Snowflake {
+
+        public double flakeX;
+        private final double flakeXO;
+        public double flakeY = -1;
+        public double dropSpeed;
+        public int maxHeight;
+        private final double verticalSpeed;
+        private final int texIndex;
+
+        public Snowflake(int flakeX, int flakeY, int dropSpeed, int maxHeight) {
+            this.flakeX = flakeX;
+            this.flakeY = flakeY;
+            this.flakeXO = flakeX;
+            this.dropSpeed = dropSpeed;
+            this.maxHeight = maxHeight;
+            this.verticalSpeed = (rand.nextFloat() - 0.5);
+            this.texIndex = rand.nextInt(4);
+        }
+
+        public void updateEffects() {
+            this.flakeY += this.dropSpeed * 0.3f;
+            this.flakeX += this.verticalSpeed * 1.5f;
+            if(this.flakeY > maxHeight) {
+                this.flakeY = 0;
+                this.flakeX = flakeXO;
+            }
+        }
+    }
     
     static class LogoBlock {
     	
diff --git a/game/client/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java b/game/client/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
index 22b038ce7..95aa3d727 100644
--- a/game/client/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
+++ b/game/client/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
@@ -245,6 +245,7 @@ public abstract class OptionsPages
                 .withComponent(new BooleanOptionComponent(mc.gameSettings.customAnimations))
                 .withComponent(new BooleanOptionComponent(mc.gameSettings.mobVariants))
                 .withComponent(new BooleanOptionComponent(mc.gameSettings.customLightmap))
+                .withComponent(new BooleanOptionComponent(mc.gameSettings.enableHolidayTextures))
             )
             .withComponent(new ShortcutComponent("gui.options.page.texture_packs.button.apply", () -> mc.texturePackList.refreshIfReady()))
             .withComponent(new OptionsCategory("gui.options.page.texture_packs.category.texture_packs.selected")
diff --git a/game/client/src/main/java/net/minecraft/client/holiday/Holiday.java b/game/client/src/main/java/net/minecraft/client/holiday/Holiday.java
index d3be6b828..b38ccbe8a 100644
--- a/game/client/src/main/java/net/minecraft/client/holiday/Holiday.java
+++ b/game/client/src/main/java/net/minecraft/client/holiday/Holiday.java
@@ -8,12 +8,27 @@ import java.util.Locale;
 import java.util.TimeZone;
 
 public class Holiday {
-    protected int month;
-    protected int day;
+    protected int monthStart;
+    protected int monthEnd;
+    protected int dayStart;
+    protected int dayEnd;
     protected String resourcePath = null;
+
+    // Single day holiday constructor
     public Holiday(Month month, int day) {
-        this.month = month.ordinal();
-        this.day = day;
+        this.monthStart = monthEnd = month.ordinal();
+        this.dayStart = dayEnd = day;
+        Holidays.allHolidays.add(this);
+    }
+
+    // Range holiday constructor
+    public Holiday(Month monthStart, int dayStart, Month monthEnd, int dayEnd) {
+        this.monthStart = monthStart.ordinal();
+        this.dayStart = dayStart;
+
+        this.monthEnd = monthEnd.ordinal();
+        this.dayEnd = dayEnd;
+
         Holidays.allHolidays.add(this);
     }
 
@@ -37,7 +52,11 @@ public class Holiday {
 
     public boolean isActive() {
         Calendar c = getLocalCalendar();
-        return c.get(Calendar.MONTH) == month && c.get(Calendar.DAY_OF_MONTH) == day;
+        //c.set(2024, Calendar.DECEMBER, 24);
+        return c.get(Calendar.MONTH) >= monthStart &&
+                c.get(Calendar.MONTH) <= monthEnd &&
+                c.get(Calendar.DAY_OF_MONTH) >= dayStart &&
+                c.get(Calendar.DAY_OF_MONTH) <= dayEnd;
     }
 
     public static Calendar getLocalCalendar() {
diff --git a/game/client/src/main/java/net/minecraft/client/holiday/Holidays.java b/game/client/src/main/java/net/minecraft/client/holiday/Holidays.java
index d5d644783..a5b51190e 100644
--- a/game/client/src/main/java/net/minecraft/client/holiday/Holidays.java
+++ b/game/client/src/main/java/net/minecraft/client/holiday/Holidays.java
@@ -9,7 +9,7 @@ public class Holidays {
     public static final List<Holiday> allThemedHolidays = new ArrayList<>();
 
     public static final Holiday HALLOWEEN = new Holiday(Month.OCTOBER, 31).setCustomResourcePath("halloween");
-    public static final Holiday XMAS = new Holiday(Month.DECEMBER, 25).setCustomResourcePath("xmas");
+    public static final Holiday XMAS = new Holiday(Month.DECEMBER, 20, Month.DECEMBER, 26).setCustomResourcePath("xmas");
     public static final Holiday NEW_YEAR = new Holiday(Month.JANUARY, 1);
 
     public static final Holiday ANNIVERSARY_MINECRAFT = new Holiday(Month.MAY, 17);
diff --git a/game/client/src/main/java/net/minecraft/client/option/GameSettings.java b/game/client/src/main/java/net/minecraft/client/option/GameSettings.java
index d964c6903..9d181f2df 100644
--- a/game/client/src/main/java/net/minecraft/client/option/GameSettings.java
+++ b/game/client/src/main/java/net/minecraft/client/option/GameSettings.java
@@ -168,6 +168,7 @@ public class GameSettings {
 	public OptionBoolean mobVariants = new OptionBoolean(this, "mobVariants", true);
 	public OptionEnum<Colorblindness> colorblindnessFix = new OptionEnum<>(this, "colorblindnessFix", Colorblindness.class, Colorblindness.NONE);
 	public OptionBoolean subtitles = new OptionBoolean(this, "subtitles", false);
+	public OptionBoolean enableHolidayTextures = new OptionBoolean(this, "enableHolidayTextures", true);
 
 	public KeyBinding keyAttack = new KeyBinding("key.attack").setDefault(InputDevice.mouse, 0);
 	public KeyBinding keyInteract = new KeyBinding("key.interact").setDefault(InputDevice.mouse, 1);
@@ -474,6 +475,10 @@ public class GameSettings {
 		if(option == rawMouseInput) {
 			mc.mouseInput.setRawInput(rawMouseInput.value);
 		}
+		if(option == enableHolidayTextures) {
+			mc.textureManager.refreshTexturesAndDisplayErrors();
+			mc.renderGlobal.loadRenderers();
+		}
 	}
 
 	public void loadOptions() {
diff --git a/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChest.java b/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChest.java
index 6833192a8..ab6f709d6 100644
--- a/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChest.java
+++ b/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChest.java
@@ -1,11 +1,11 @@
 package net.minecraft.client.render.block.model;
 
+import net.minecraft.client.render.tessellator.Tessellator;
 import net.minecraft.client.render.texture.stitcher.IconCoordinate;
 import net.minecraft.client.render.texture.stitcher.TextureRegistry;
-import net.minecraft.core.block.Block;
-import net.minecraft.core.block.BlockLogic;
-import net.minecraft.core.block.BlockLogicChest;
+import net.minecraft.core.block.*;
 import net.minecraft.core.util.helper.Axis;
+import net.minecraft.core.util.helper.Direction;
 import net.minecraft.core.util.helper.Side;
 import net.minecraft.core.world.WorldSource;
 
@@ -15,6 +15,8 @@ public class BlockModelChest<T extends BlockLogic> extends BlockModelStandard<T>
     protected IconCoordinate chestFrontRight;
     protected IconCoordinate chestBackLeft;
     protected IconCoordinate chestBackRight;
+    protected IconCoordinate chestTopLeft;
+    protected IconCoordinate chestTopRight;
     protected IconCoordinate chestSide;
     protected IconCoordinate chestTop;
     public BlockModelChest(Block<T> block, String rootKey) {
@@ -22,28 +24,65 @@ public class BlockModelChest<T extends BlockLogic> extends BlockModelStandard<T>
         chestFrontSingle = TextureRegistry.getTexture(rootKey + "front");
         chestFrontLeft = TextureRegistry.getTexture(rootKey + "left_front");
         chestFrontRight = TextureRegistry.getTexture(rootKey + "right_front");
+        chestTopLeft = TextureRegistry.getTexture(rootKey + "top_left");
+        chestTopRight = TextureRegistry.getTexture(rootKey + "top_right");
         chestBackLeft = TextureRegistry.getTexture(rootKey + "left_back");
         chestBackRight = TextureRegistry.getTexture(rootKey + "right_back");
         chestSide = TextureRegistry.getTexture(rootKey + "side");
         chestTop = TextureRegistry.getTexture(rootKey + "top");
     }
 
+    @Override
+    public boolean render(Tessellator tessellator, int x, int y, int z) {
+        int meta = renderBlocks.blockAccess.getBlockMetadata(x, y, z);
+        final Direction dir = BlockLogicChest.getDirectionFromMeta(meta);
+        switch (dir) {
+            case NORTH:
+                renderBlocks.uvRotateTop = 3;
+                break;
+
+            case EAST:
+                renderBlocks.uvRotateTop = 2;
+                break;
+
+            case WEST:
+                renderBlocks.uvRotateTop = 1;
+                break;
+        }
+
+        renderStandardBlock(tessellator, block.getBlockBoundsFromState(renderBlocks.blockAccess, x, y, z), x, y, z);
+        resetRenderBlocks();
+        return true;
+    }
+
     @Override
     public IconCoordinate getBlockTexture(WorldSource blockAccess, int x, int y, int z, Side side) {
         int meta = blockAccess.getBlockMetadata(x, y, z);
 
-        if(side == Side.TOP || side == Side.BOTTOM) {
+        Side facing = BlockLogicChest.getDirectionFromMeta(meta).getSide();
+        BlockLogicChest.Type type = BlockLogicChest.getTypeFromMeta(meta);
+
+        if(side == Side.TOP) {
+            if(type == BlockLogicChest.Type.RIGHT) {
+                return chestTopRight;
+            }
+            if(type == BlockLogicChest.Type.LEFT) {
+                return chestTopLeft;
+            }
+
             return chestTop;
         }
 
-        Side facing = BlockLogicChest.getDirectionFromMeta(meta).getSide();
-        BlockLogicChest.Type type = BlockLogicChest.getTypeFromMeta(meta);
+        if(side == Side.BOTTOM) {
+            return chestTop;
+        }
 
         if(type == BlockLogicChest.Type.SINGLE) {
             if(side == facing) {
                 return chestFrontSingle;
             }
         }
+
         if(type == BlockLogicChest.Type.LEFT) {
             if(side == facing) {
                 return chestFrontLeft;
diff --git a/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChestPainted.java b/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChestPainted.java
index fb8b6435e..785cc6e31 100644
--- a/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChestPainted.java
+++ b/game/client/src/main/java/net/minecraft/client/render/block/model/BlockModelChestPainted.java
@@ -19,11 +19,13 @@ public class BlockModelChestPainted<T extends BlockLogic> extends BlockModelChes
     public static final int TEX_RIGHT_BACK = 4;
     public static final int TEX_SIDE = 5;
     public static final int TEX_TOP = 6;
+    public static final int TEX_LEFT_TOP = 7;
+    public static final int TEX_RIGHT_TOP = 8;
 
     static {
         for (DyeColor c : DyeColor.blockOrderedColors()){
             String rootKey = "minecraft:block/chest/planks_" + c.colorID + "/";
-            texCoords[c.blockMeta] = new IconCoordinate[7];
+            texCoords[c.blockMeta] = new IconCoordinate[9];
             texCoords[c.blockMeta][TEX_SINGLE_FRONT] = TextureRegistry.getTexture(rootKey + "front");
             texCoords[c.blockMeta][TEX_LEFT_FRONT] = TextureRegistry.getTexture(rootKey + "left_front");
             texCoords[c.blockMeta][TEX_RIGHT_FRONT] = TextureRegistry.getTexture(rootKey + "right_front");
@@ -31,6 +33,8 @@ public class BlockModelChestPainted<T extends BlockLogic> extends BlockModelChes
             texCoords[c.blockMeta][TEX_RIGHT_BACK] = TextureRegistry.getTexture(rootKey + "right_back");
             texCoords[c.blockMeta][TEX_SIDE] = TextureRegistry.getTexture(rootKey + "side");
             texCoords[c.blockMeta][TEX_TOP] = TextureRegistry.getTexture(rootKey + "top");
+            texCoords[c.blockMeta][TEX_LEFT_TOP] = TextureRegistry.getTexture(rootKey + "top_left");
+            texCoords[c.blockMeta][TEX_RIGHT_TOP] = TextureRegistry.getTexture(rootKey + "top_right");
         }
     }
     public BlockModelChestPainted(Block<T> block) {
@@ -42,18 +46,26 @@ public class BlockModelChestPainted<T extends BlockLogic> extends BlockModelChes
         int meta = blockAccess.getBlockMetadata(x, y, z);
         int color = meta >> 4;
 
+        Side facing = BlockLogicChest.getDirectionFromMeta(meta).getSide();
+        BlockLogicChest.Type type = BlockLogicChest.getTypeFromMeta(meta);
+
         if(side == Side.TOP || side == Side.BOTTOM) {
+            if(type == BlockLogicChest.Type.LEFT) {
+                return texCoords[color][7];
+            }
+            if(type == BlockLogicChest.Type.RIGHT) {
+                return texCoords[color][8];
+            }
+
             return texCoords[color][6];
         }
 
-        Side facing = BlockLogicChest.getDirectionFromMeta(meta).getSide();
-        BlockLogicChest.Type type = BlockLogicChest.getTypeFromMeta(meta);
-
         if(type == BlockLogicChest.Type.SINGLE) {
             if(side == facing) {
                 return texCoords[color][TEX_SINGLE_FRONT];
             }
         }
+
         if(type == BlockLogicChest.Type.LEFT) {
             if(side == facing) {
                 return texCoords[color][TEX_LEFT_FRONT];
diff --git a/game/client/src/main/java/net/minecraft/client/render/customatlas/CustomAtlasHandler.java b/game/client/src/main/java/net/minecraft/client/render/customatlas/CustomAtlasHandler.java
index 56a817ecc..098af7ceb 100644
--- a/game/client/src/main/java/net/minecraft/client/render/customatlas/CustomAtlasHandler.java
+++ b/game/client/src/main/java/net/minecraft/client/render/customatlas/CustomAtlasHandler.java
@@ -24,7 +24,6 @@ public class CustomAtlasHandler {
 	private static Atlas legacyItemsAtlas = null;
 	
 	public static Minecraft mc = Minecraft.getMinecraft();
-	
 	private static Map<String, BufferedImage> textureOverrides = new HashMap<>();
 	
 	private static void loadLegacyTiles() {
@@ -45,7 +44,7 @@ public class CustomAtlasHandler {
 		
 		List<TexturePack> texturePacks = mc.texturePackList.selectedPacks;
 		List<String> overrides = new ArrayList<>();
-		
+
 		log("Active Texture Packs: ");
 		for(int texturePackIndex=0; texturePackIndex < texturePacks.size(); texturePackIndex++) {
 			TexturePack texturePack = texturePacks.get(texturePackIndex);
@@ -120,7 +119,7 @@ public class CustomAtlasHandler {
 			AtlasTile atlasTile = atlasTiles.get(tileIndex);
 			
 			BufferedImage tileImage = image.getSubimage(tileWidth * atlasTile.x, tileHeight * atlasTile.y, tileWidth, tileHeight);
-			
+
 			String path = pathPrefix + atlasTile.name + ".png";
 			textureOverrides.put(path, tileImage);
 		}
diff --git a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererBiped.java b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererBiped.java
index f3d769fac..a735441e6 100644
--- a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererBiped.java
+++ b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererBiped.java
@@ -2,20 +2,32 @@ package net.minecraft.client.render.entity;
 
 import net.minecraft.client.render.item.model.ItemModelDispatcher;
 import net.minecraft.client.render.model.ModelBiped;
+import net.minecraft.client.render.model.ModelZombie;
 import net.minecraft.client.render.tessellator.Tessellator;
 import net.minecraft.core.entity.Mob;
+import net.minecraft.core.entity.monster.MobZombieArmored;
 import net.minecraft.core.item.ItemStack;
 import org.lwjgl.opengl.GL11;
 
 public class MobRendererBiped<T extends Mob> extends MobRenderer<T>
 {
-
+	private final ModelBiped modelArmor;
     public MobRendererBiped(ModelBiped model, float shadowSize)
     {
         super(model, shadowSize);
         modelBipedMain = model;
+		modelArmor = new ModelBiped(0.5F);
     }
 
+	protected boolean prepareArmor(MobZombieArmored zombie, int renderPass, float partialTick)
+	{
+		bindTexture("/assets/minecraft/textures/armor/xmas.png");
+		ModelBiped model = modelArmor;
+		model.head.visible = true;
+		setArmorModel(model);
+		return true;
+	}
+
 	@Override
 	protected void renderAdditional(T entity, float f) {
 		ItemStack itemstack = entity.getHeldItem();
diff --git a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePack.java b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePack.java
index 2b5b706a7..14ef09aa1 100644
--- a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePack.java
+++ b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePack.java
@@ -46,7 +46,7 @@ public abstract class TexturePack {
 
 	public InputStream getResourceAsStream(String s)
 	{
-		if (Holidays.getCurrentThemedHoliday() != null) {
+		if (Holidays.getCurrentThemedHoliday() != null && Minecraft.getMinecraft().gameSettings.enableHolidayTextures.value) {
 			assert Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() != null : "Current themed holiday must have a theme!";
 			String holidayPath = ("/holidays/" + Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() + "/" + s);
 			InputStream holidayStream = TexturePack.class.getResourceAsStream(holidayPath);
diff --git a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackCustom.java b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackCustom.java
index f66503639..622bd99e6 100644
--- a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackCustom.java
+++ b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackCustom.java
@@ -190,7 +190,7 @@ public class TexturePackCustom extends TexturePack
 	}
 	private InputStream getResourceAsStream(String path, boolean firstCall)
 	{
-		if (firstCall && Holidays.getCurrentThemedHoliday() != null) {
+		if (firstCall && Holidays.getCurrentThemedHoliday() != null && Minecraft.getMinecraft().gameSettings.enableHolidayTextures.value) {
 			assert Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() != null : "Current themed holiday must have a theme!";
 			String holidayPath = ("/holidays/" + Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() + "/" + path);
 			InputStream holidayStream = getResourceAsStream(holidayPath, false);
diff --git a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackDefault.java b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackDefault.java
index 7428e1650..dd90eff40 100644
--- a/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackDefault.java
+++ b/game/client/src/main/java/net/minecraft/client/render/texturepack/TexturePackDefault.java
@@ -8,6 +8,7 @@ import javax.imageio.ImageIO;
 
 import com.mojang.logging.LogUtils;
 import net.minecraft.client.Minecraft;
+import net.minecraft.client.holiday.Holidays;
 import net.minecraft.client.render.texture.TextureBuffered;
 import org.slf4j.Logger;
 
@@ -63,9 +64,19 @@ public class TexturePackDefault extends TexturePack
 		try
         {
 			InputStream stream = TexturePackDefault.class.getResourceAsStream(file);
-			boolean a = stream != null;
-			if(stream != null) stream.close();
-			return a;
+            if (stream != null) {
+                stream.close();
+                return true;
+            } else if (Minecraft.getMinecraft().gameSettings.enableHolidayTextures.value && Holidays.getCurrentThemedHoliday() != null) {
+                assert Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() != null : "Current themed holiday must have a theme!";
+                String holidayPath = ("/holidays/" + Holidays.getCurrentThemedHoliday().getCustomResourcesSubPath() + "/" + file);
+                InputStream holidayStream = TexturePack.class.getResourceAsStream(holidayPath);
+                if (holidayStream != null) {
+                    holidayStream.close();
+                    return true;
+                }
+            }
+            return false;
 		}
         catch (Exception e)
         {
diff --git a/game/client/src/main/resources/assets/minecraft/textures/armor/xmas.png b/game/client/src/main/resources/assets/minecraft/textures/armor/xmas.png
new file mode 100644
index 000000000..f981f70f9
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/armor/xmas.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_left.png
new file mode 100644
index 000000000..1b2da1d2d
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_right.png
new file mode 100644
index 000000000..6664ad20b
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/front.png
index b46ddd747..c2cf1007d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_back.png
index df22301ba..3a474e375 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_front.png
index 7093539cf..343502a9f 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_back.png
index 18a255ae9..26ccc9d02 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_front.png
index 7a2e32564..7fc57b01d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/side.png
index 620e54301..70c1c4c90 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top.png
index 96e7caaf1..0a57677b3 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_left.png
new file mode 100644
index 000000000..10243e80c
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_right.png
new file mode 100644
index 000000000..65dfa52eb
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_black/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/front.png
index 75467c110..22da48be9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_back.png
index a3497e04f..8d25252d5 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_front.png
index dbc4ca068..22fb87793 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_back.png
index f8fcf0d2e..e956284a0 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_front.png
index c74f6f04b..9053b741c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/side.png
index e59d7eff6..947b89800 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top.png
index f7c61f536..fb5d3392f 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_left.png
new file mode 100644
index 000000000..eab08ad8c
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_right.png
new file mode 100644
index 000000000..eb76f7ec5
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_blue/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/front.png
index e32aabe44..c37564287 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_back.png
index 62d4affb3..c0a698793 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_front.png
index 86603d697..a7e3cadf9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_back.png
index 309efaa86..92421a92e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_front.png
index 18c802ee6..96687ae1c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/side.png
index 5d5466c4b..d2b9bf924 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top.png
index 54c777edc..32eba40fa 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_left.png
new file mode 100644
index 000000000..467094efd
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_right.png
new file mode 100644
index 000000000..59c2cf311
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_brown/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/front.png
index f1150f9dc..ff5ce16dc 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_back.png
index 306065f19..25680073c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_front.png
index f22b219c4..cf62856d7 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_back.png
index c9d22f501..1e104e134 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_front.png
index 857eb1f63..24a00ffcb 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/side.png
index 9087a10f8..0fbd89b77 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top.png
index 7693a6090..ef5bae95c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_left.png
new file mode 100644
index 000000000..ee8649c33
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_right.png
new file mode 100644
index 000000000..21f0705fd
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_cyan/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/front.png
index 9cdf1e72a..f1d878f19 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_back.png
index 833705144..1e6b35127 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_front.png
index 770a18e9b..ace6d4aed 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_back.png
index 8b2834aeb..fc2ae56c6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_front.png
index b4725ad62..de862205c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/side.png
index 43697da66..f48918bf2 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top.png
index e5eb14eca..dc55ecd2c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_left.png
new file mode 100644
index 000000000..068c93530
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_right.png
new file mode 100644
index 000000000..0684a92c1
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_gray/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/front.png
index 4737da5a3..317683a14 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_back.png
index 5ef8e91e1..11cd63908 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_front.png
index 1af7e4366..b850511ae 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_back.png
index 0c0861824..4530efc4e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_front.png
index a10a8dec8..afe64bfc2 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/side.png
index 3f47173cb..651beeb0e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top.png
index 0c28c35fe..35019d497 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_left.png
new file mode 100644
index 000000000..8a55b09b4
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_right.png
new file mode 100644
index 000000000..7d9eaaac1
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_green/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/front.png
index 25b9a5406..0d8a583aa 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png
index 035a75174..6ebc522b8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png
index f6cf08793..d3d385987 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png
index 20679329e..c5979dd23 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png
index 80fb8ae1d..7ea35a680 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/side.png
index 37844bb5e..4b22ca79d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top.png
index 8063f84b9..6198650a8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png
new file mode 100644
index 000000000..833fd0f90
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png
new file mode 100644
index 000000000..5f4b7d804
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/front.png
index 4bad24867..d17f1492a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_back.png
index faeb838ae..dcbe8f8cf 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_front.png
index f5a68611a..48b4d0e46 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_back.png
index 2b7531591..d7a75d566 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_front.png
index 2b979633f..2d706c542 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/side.png
index b8bc36464..3b0ca5715 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top.png
index ef99ff365..6bec0147b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_left.png
new file mode 100644
index 000000000..87b645c2f
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_right.png
new file mode 100644
index 000000000..99559ca9b
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_lime/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/front.png
index 6df514637..f8dbae79e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_back.png
index 69fc97547..f425cde3e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_front.png
index 20183ed18..cc19a6afa 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_back.png
index 0365d7630..ce00c2f81 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_front.png
index 263f144a3..80feb1327 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/side.png
index 00845a279..5b1a09098 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top.png
index 089aa3336..2b23e4b68 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_left.png
new file mode 100644
index 000000000..7ae4c46da
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_right.png
new file mode 100644
index 000000000..5833c25ff
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_magenta/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/front.png
index 0abaf9780..6c469a41f 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_back.png
index 03660db66..9821360ad 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_front.png
index 68aaec316..0c5a8b63c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_back.png
index 7be8a6b00..a3e3b26ad 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_front.png
index 28ce981b6..444f06e40 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/side.png
index 03a24970c..0221a8ff5 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top.png
index 016c706dc..44ea3fc78 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_left.png
new file mode 100644
index 000000000..97ffab8e4
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_right.png
new file mode 100644
index 000000000..3f7c4e647
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_orange/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/front.png
index 9c2fbe8bd..9c69b74b8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_back.png
index 10d57d04d..14037a884 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_front.png
index 70cf847df..77674459b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_back.png
index 36a884f16..1b8617edc 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_front.png
index 808fe6b1c..0eb2c07bd 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/side.png
index 05f31d3e6..597f8769a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top.png
index 0569c1dfd..fc8f227a4 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_left.png
new file mode 100644
index 000000000..44008b905
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_right.png
new file mode 100644
index 000000000..7e8f16ce0
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_pink/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/front.png
index de2a8ce5b..cef7ea053 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_back.png
index b44fbc369..6b14981b9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_front.png
index dcf78329c..b17249b44 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_back.png
index 0f1e4f48d..151126ed6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_front.png
index 6c4819b3e..b6ab9e9ef 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/side.png
index 9b42d96aa..983cda8e9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top.png
index 1e6df8d38..98feba4b9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_left.png
new file mode 100644
index 000000000..ad5da2bc9
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_right.png
new file mode 100644
index 000000000..85df09e87
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_purple/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/front.png
index 7d2dfbebb..7610d1156 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_back.png
index d79ae51d6..557719eb8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_front.png
index a5825c3c2..f4c55705d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_back.png
index f708642e6..544776d4f 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_front.png
index 9524e5d49..894cbe0a6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/side.png
index be36b352b..faececc56 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top.png
index 54850e1a8..d546af4b9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_left.png
new file mode 100644
index 000000000..342949d46
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_right.png
new file mode 100644
index 000000000..c6f266fe0
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_red/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/front.png
index 6ac1d5612..008e41844 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_back.png
index 1bbad4e79..eba9bbdbc 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_front.png
index 8dc0f365b..ed2f8c011 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_back.png
index 25b37d71a..90a768836 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_front.png
index 8fb0bdb68..5b1b9a320 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/side.png
index e41c7c2fd..c5d7c84c4 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top.png
index 5c45f2b71..9f945a354 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_left.png
new file mode 100644
index 000000000..562242723
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_right.png
new file mode 100644
index 000000000..21e970663
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_silver/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/front.png
index b7820bd26..1095cac04 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_back.png
index b221ab949..8c718aec9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_front.png
index 21e1a8eaf..786d93b4d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_back.png
index 613cd574e..66c31fb06 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_front.png
index 53e444e02..d07a40406 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/side.png
index efa0780c6..2281a8225 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top.png
index 9cb995f97..fbb7ba307 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_left.png
new file mode 100644
index 000000000..6b06c7b60
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_right.png
new file mode 100644
index 000000000..09b19e073
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_white/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/front.png
index d4491924d..d85b49934 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_back.png
index e192340b3..f6501b0b9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_front.png
index 59c51a769..75e94c5c1 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/left_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_back.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_back.png
index e535472e6..90979aa02 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_back.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_back.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_front.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_front.png
index 9e5aefd51..de1538681 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_front.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/right_front.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/side.png
index 3fcdb2711..313ee1048 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top.png
index 2148ba59f..8c882c60d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_left.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_left.png
new file mode 100644
index 000000000..265747797
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_left.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_right.png b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_right.png
new file mode 100644
index 000000000..394e04616
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/chest/planks_yellow/top_right.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/bottom.png
index 1d63f40c0..528626cac 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/frame_top.png
index b1eadf216..98fdf7ee2 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/top.png
index fe9ac6aba..d69a1e0d8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_black/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/bottom.png
index 971bcd5ce..840f9e42d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/frame_top.png
index 48b4a1441..53e3feaa6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/top.png
index 51f239e85..bb8fc6a42 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_blue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/bottom.png
index c7a45b426..1d5d3b623 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/frame_top.png
index 7b1fcad0a..4414f1c8c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/top.png
index 08e2ee19c..c841606ac 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_brown/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/bottom.png
index 9c83abb5c..37c303ed6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/frame_top.png
index d978a0828..96e977bde 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/top.png
index 36f99bb2c..c57db8778 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_cyan/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/bottom.png
index 7b09508b6..31e2645b4 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/frame_top.png
index f244fd735..70be6853d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/top.png
index f2bb07153..bf52e1cbe 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_gray/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/bottom.png
index 05b9d7ac5..dbd7abee8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/frame_top.png
index 3f4adcf76..bf73fafe0 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/top.png
index 65cf3071c..8327b9d45 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_green/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/bottom.png
index 266ecf43f..cb524de51 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/frame_top.png
index 7b732e1b1..3a68d72e9 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/top.png
index 9c332ea4b..733262ee1 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lightblue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/bottom.png
index 21e201c94..ca27ab267 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/frame_top.png
index 51c369abc..982558346 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/top.png
index 7d0b30483..d9b36feb0 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_lime/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/bottom.png
index 7c820ac1a..ca6d9cd18 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/frame_top.png
index f69ad5fd5..85b0cd184 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/top.png
index 03c1822ba..bd6492fe8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_magenta/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/bottom.png
index 42a0bfd56..1f0015a1a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/frame_top.png
index 5afc5f5de..f2247c356 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/top.png
index b119c8478..a41ab9421 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_orange/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/bottom.png
index 522c718bb..af217dad4 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/frame_top.png
index e1e49a239..c3fd28d2a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/top.png
index e0dcb6315..2a57f2502 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_pink/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/bottom.png
index 44f9b5671..2946db91e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/frame_top.png
index a2156385d..ba7f0ec5f 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/top.png
index 196a1827d..8fcdff0e6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_purple/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/bottom.png
index b046e28a6..81107cf78 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/frame_top.png
index 8b8620031..f5c2614cd 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/top.png
index e262fc545..cc485892b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_red/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/bottom.png
index 8f06ee8be..a05d2316b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/frame_top.png
index 644e222fe..4203477a8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/top.png
index 4cd1744a8..3fbf4a93d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_silver/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/bottom.png
index b031e5397..8df13772b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/frame_top.png
index 19f344088..4bfc89232 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/top.png
index c4a810d05..b1e308d5c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_white/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/bottom.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/bottom.png
index 9fd7ecb9f..bc43d2f26 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/bottom.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/bottom.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/frame_top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/frame_top.png
index 91810225d..c4d7b3f16 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/frame_top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/frame_top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/top.png
index f52440eff..8253ea133 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/door/planks_yellow/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.png b/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.png
new file mode 100644
index 000000000..5bfce29eb
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.tiles b/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.tiles
new file mode 100644
index 000000000..fbd291b54
--- /dev/null
+++ b/game/client/src/main/resources/assets/minecraft/textures/block/painted_wood.tiles
@@ -0,0 +1,241 @@
+size=16x17
+0,0=planks/black
+1,0=planks/blue
+2,0=planks/gray
+3,0=planks/lightblue
+4,0=chest/planks_black/top_left
+5,0=chest/planks_black/top_right
+6,0=chest/planks_black/top
+7,0=chest/planks_blue/top_left
+8,0=chest/planks_blue/top_right
+9,0=chest/planks_blue/top
+10,0=chest/planks_gray/top_left
+11,0=chest/planks_gray/top_right
+12,0=chest/planks_gray/top
+13,0=chest/planks_lightblue/top_left
+14,0=chest/planks_lightblue/top_right
+15,0=chest/planks_lightblue/top
+0,1=planks/red
+1,1=planks/purple
+2,1=planks/pink
+3,1=planks/magenta
+4,1=chest/planks_black/left_front
+5,1=chest/planks_black/right_front
+6,1=chest/planks_black/front
+7,1=chest/planks_blue/left_front
+8,1=chest/planks_blue/right_front
+9,1=chest/planks_blue/front
+10,1=chest/planks_gray/left_front
+11,1=chest/planks_gray/right_front
+12,1=chest/planks_gray/front
+13,1=chest/planks_lightblue/left_front
+14,1=chest/planks_lightblue/right_front
+15,1=chest/planks_lightblue/front
+0,2=planks/green
+1,2=planks/cyan
+2,2=planks/lime
+3,2=planks/orange
+4,2=chest/planks_black/left_back
+5,2=chest/planks_black/right_back
+6,2=chest/planks_black/side
+7,2=chest/planks_blue/left_back
+8,2=chest/planks_blue/right_back
+9,2=chest/planks_blue/side
+10,2=chest/planks_gray/left_back
+11,2=chest/planks_gray/right_back
+12,2=chest/planks_gray/side
+13,2=chest/planks_lightblue/left_back
+14,2=chest/planks_lightblue/right_back
+15,2=chest/planks_lightblue/side
+0,3=planks/brown
+1,3=planks/silver
+2,3=planks/yellow
+3,3=planks/white
+4,3=chest/planks_red/top_left
+5,3=chest/planks_red/top_right
+6,3=chest/planks_red/top
+7,3=chest/planks_purple/top_left
+8,3=chest/planks_purple/top_right
+9,3=chest/planks_purple/top
+10,3=chest/planks_pink/top_left
+11,3=chest/planks_pink/top_right
+12,3=chest/planks_pink/top
+13,3=chest/planks_magenta/top_left
+14,3=chest/planks_magenta/top_right
+15,3=chest/planks_magenta/top
+4,4=chest/planks_red/left_front
+5,4=chest/planks_red/right_front
+6,4=chest/planks_red/front
+7,4=chest/planks_purple/left_front
+8,4=chest/planks_purple/right_front
+9,4=chest/planks_purple/front
+10,4=chest/planks_pink/left_front
+11,4=chest/planks_pink/right_front
+12,4=chest/planks_pink/front
+13,4=chest/planks_magenta/left_front
+14,4=chest/planks_magenta/right_front
+15,4=chest/planks_magenta/front
+4,5=chest/planks_red/left_back
+5,5=chest/planks_red/right_back
+6,5=chest/planks_red/side
+7,5=chest/planks_purple/left_back
+8,5=chest/planks_purple/right_back
+9,5=chest/planks_purple/side
+10,5=chest/planks_pink/left_back
+11,5=chest/planks_pink/right_back
+12,5=chest/planks_pink/side
+13,5=chest/planks_magenta/left_back
+14,5=chest/planks_magenta/right_back
+15,5=chest/planks_magenta/side
+4,6=chest/planks_green/top_left
+5,6=chest/planks_green/top_right
+6,6=chest/planks_green/top
+7,6=chest/planks_cyan/top_left
+8,6=chest/planks_cyan/top_right
+9,6=chest/planks_cyan/top
+10,6=chest/planks_lime/top_left
+11,6=chest/planks_lime/top_right
+12,6=chest/planks_lime/top
+13,6=chest/planks_orange/top_left
+14,6=chest/planks_orange/top_right
+15,6=chest/planks_orange/top
+4,7=chest/planks_green/left_front
+5,7=chest/planks_green/right_front
+6,7=chest/planks_green/front
+7,7=chest/planks_cyan/left_front
+8,7=chest/planks_cyan/right_front
+9,7=chest/planks_cyan/front
+10,7=chest/planks_lime/left_front
+11,7=chest/planks_lime/right_front
+12,7=chest/planks_lime/front
+13,7=chest/planks_orange/left_front
+14,7=chest/planks_orange/right_front
+15,7=chest/planks_orange/front
+4,8=chest/planks_green/left_back
+5,8=chest/planks_green/right_back
+6,8=chest/planks_green/side
+7,8=chest/planks_cyan/left_back
+8,8=chest/planks_cyan/right_back
+9,8=chest/planks_cyan/side
+10,8=chest/planks_lime/left_back
+11,8=chest/planks_lime/right_back
+12,8=chest/planks_lime/side
+13,8=chest/planks_orange/left_back
+14,8=chest/planks_orange/right_back
+15,8=chest/planks_orange/side
+4,9=chest/planks_brown/top_left
+5,9=chest/planks_brown/top_right
+6,9=chest/planks_brown/top
+7,9=chest/planks_silver/top_left
+8,9=chest/planks_silver/top_right
+9,9=chest/planks_silver/top
+10,9=chest/planks_yellow/top_left
+11,9=chest/planks_yellow/top_right
+12,9=chest/planks_yellow/top
+13,9=chest/planks_white/top_left
+14,9=chest/planks_white/top_right
+15,9=chest/planks_white/top
+4,10=chest/planks_brown/left_front
+5,10=chest/planks_brown/right_front
+6,10=chest/planks_brown/front
+7,10=chest/planks_silver/left_front
+8,10=chest/planks_silver/right_front
+9,10=chest/planks_silver/front
+10,10=chest/planks_yellow/left_front
+11,10=chest/planks_yellow/right_front
+12,10=chest/planks_yellow/front
+13,10=chest/planks_white/left_front
+14,10=chest/planks_white/right_front
+15,10=chest/planks_white/front
+4,11=chest/planks_brown/left_back
+5,11=chest/planks_brown/right_back
+6,11=chest/planks_brown/side
+7,11=chest/planks_silver/left_back
+8,11=chest/planks_silver/right_back
+9,11=chest/planks_silver/side
+10,11=chest/planks_yellow/left_back
+11,11=chest/planks_yellow/right_back
+12,11=chest/planks_yellow/side
+13,11=chest/planks_white/left_back
+14,11=chest/planks_white/right_back
+15,11=chest/planks_white/side
+0,12=trapdoor/planks_black/side
+1,12=trapdoor/planks_red/side
+2,12=trapdoor/planks_green/side
+3,12=trapdoor/planks_brown/side
+4,12=trapdoor/planks_blue/side
+5,12=trapdoor/planks_purple/side
+6,12=trapdoor/planks_cyan/side
+7,12=trapdoor/planks_silver/side
+8,12=trapdoor/planks_gray/side
+9,12=trapdoor/planks_pink/side
+10,12=trapdoor/planks_lime/side
+11,12=trapdoor/planks_yellow/side
+12,12=trapdoor/planks_lightblue/side
+13,12=trapdoor/planks_magenta/side
+14,12=trapdoor/planks_orange/side
+15,12=trapdoor/planks_white/side
+0,13=trapdoor/planks_black/top
+1,13=trapdoor/planks_red/top
+2,13=trapdoor/planks_green/top
+3,13=trapdoor/planks_brown/top
+4,13=trapdoor/planks_blue/top
+5,13=trapdoor/planks_purple/top
+6,13=trapdoor/planks_cyan/top
+7,13=trapdoor/planks_silver/top
+8,13=trapdoor/planks_gray/top
+9,13=trapdoor/planks_pink/top
+10,13=trapdoor/planks_lime/top
+11,13=trapdoor/planks_yellow/top
+12,13=trapdoor/planks_lightblue/top
+13,13=trapdoor/planks_magenta/top
+14,13=trapdoor/planks_orange/top
+15,13=trapdoor/planks_white/top
+0,14=door/planks_black/top
+1,14=door/planks_red/top
+2,14=door/planks_green/top
+3,14=door/planks_brown/top
+4,14=door/planks_blue/top
+5,14=door/planks_purple/top
+6,14=door/planks_cyan/top
+7,14=door/planks_silver/top
+8,14=door/planks_gray/top
+9,14=door/planks_pink/top
+10,14=door/planks_lime/top
+11,14=door/planks_yellow/top
+12,14=door/planks_lightblue/top
+13,14=door/planks_magenta/top
+14,14=door/planks_orange/top
+15,14=door/planks_white/top
+0,15=door/planks_black/bottom
+1,15=door/planks_red/bottom
+2,15=door/planks_green/bottom
+3,15=door/planks_brown/bottom
+4,15=door/planks_blue/bottom
+5,15=door/planks_purple/bottom
+6,15=door/planks_cyan/bottom
+7,15=door/planks_silver/bottom
+8,15=door/planks_gray/bottom
+9,15=door/planks_pink/bottom
+10,15=door/planks_lime/bottom
+11,15=door/planks_yellow/bottom
+12,15=door/planks_lightblue/bottom
+13,15=door/planks_magenta/bottom
+14,15=door/planks_orange/bottom
+15,15=door/planks_white/bottom
+0,16=door/planks_black/frame_top
+1,16=door/planks_red/frame_top
+2,16=door/planks_green/frame_top
+3,16=door/planks_brown/frame_top
+4,16=door/planks_blue/frame_top
+5,16=door/planks_purple/frame_top
+6,16=door/planks_cyan/frame_top
+7,16=door/planks_silver/frame_top
+8,16=door/planks_gray/frame_top
+9,16=door/planks_pink/frame_top
+10,16=door/planks_lime/frame_top
+11,16=door/planks_yellow/frame_top
+12,16=door/planks_lightblue/frame_top
+13,16=door/planks_magenta/frame_top
+14,16=door/planks_orange/frame_top
+15,16=door/planks_white/frame_top
\ No newline at end of file
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/side.png
index 0bf8e9fd0..d17d11e1c 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/top.png
index b1eadf216..14f2497ba 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_black/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/side.png
index 36dac5a22..6ebfa3fbe 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/top.png
index 48b4a1441..b4484f6fe 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_blue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/side.png
index b6995ed45..630f83eb0 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/top.png
index 7b1fcad0a..249f80ee7 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_brown/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/side.png
index f2eee0522..114e0fd0d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/top.png
index d978a0828..a70e6e144 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_cyan/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/side.png
index ab21cea10..e98410457 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/top.png
index f244fd735..21dab6a84 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_gray/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/side.png
index 055e2b307..dc40c0b1e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/top.png
index 3f4adcf76..c7ff1f731 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_green/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/side.png
index 0c6cbb5fe..840c1ad8d 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/top.png
index 7b732e1b1..0bfc5bf5a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lightblue/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/side.png
index 9b670b766..b6aabf7d8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/top.png
index 51c369abc..e2c2a3f0e 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_lime/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/side.png
index 5cf108c13..8cb05b183 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/top.png
index f69ad5fd5..890993c05 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_magenta/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/side.png
index 781ec48c5..47da26e68 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/top.png
index 5afc5f5de..56e4b6e09 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_orange/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/side.png
index b11527525..16a270123 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/top.png
index e1e49a239..38240cd9a 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_pink/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/side.png
index a7915dde6..460412979 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/top.png
index a2156385d..4995cd44b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_purple/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/side.png
index d2e5ec1b9..1599ea1dd 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/top.png
index 8b8620031..3fa2721cc 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_red/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/side.png
index b69967bb2..30fd22f04 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/top.png
index 644e222fe..3e5b41f6b 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_silver/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/side.png
index 9db25bb59..cc1572459 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/top.png
index 19f344088..3dbd4bb49 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_white/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/side.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/side.png
index 08e358696..27d8540d8 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/side.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/side.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/top.png b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/top.png
index 91810225d..d950e25f6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/top.png and b/game/client/src/main/resources/assets/minecraft/textures/block/trapdoor/planks_yellow/top.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/entity/wolf_tame/0.png b/game/client/src/main/resources/assets/minecraft/textures/entity/wolf_tame/0.png
index 159f45b54..e59ae6bb6 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/entity/wolf_tame/0.png and b/game/client/src/main/resources/assets/minecraft/textures/entity/wolf_tame/0.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/entity/zombie/0.png b/game/client/src/main/resources/assets/minecraft/textures/entity/zombie/0.png
index 0ab708952..0055bc140 100644
Binary files a/game/client/src/main/resources/assets/minecraft/textures/entity/zombie/0.png and b/game/client/src/main/resources/assets/minecraft/textures/entity/zombie/0.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/title/snowflake.png b/game/client/src/main/resources/assets/minecraft/textures/gui/title/snowflake.png
new file mode 100644
index 000000000..88bcc1203
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/gui/title/snowflake.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/front.png
new file mode 100644
index 000000000..d3c4db572
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_back.png
new file mode 100644
index 000000000..385234862
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_front.png
new file mode 100644
index 000000000..385234862
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_back.png
new file mode 100644
index 000000000..00547db65
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_front.png
new file mode 100644
index 000000000..00547db65
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/side.png
new file mode 100644
index 000000000..d3c4db572
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top.png
new file mode 100644
index 000000000..75cf2a5f8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_left.png
new file mode 100644
index 000000000..795fd7aca
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_right.png
new file mode 100644
index 000000000..22ca6b94b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/front.png
new file mode 100644
index 000000000..28d9c562c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_back.png
new file mode 100644
index 000000000..ea55b8994
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_front.png
new file mode 100644
index 000000000..ea55b8994
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_side.png
new file mode 100644
index 000000000..b726aeb09
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/left_side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_back.png
new file mode 100644
index 000000000..7f5aded6b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_front.png
new file mode 100644
index 000000000..7f5aded6b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_side.png
new file mode 100644
index 000000000..292f0ca3e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/right_side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/side.png
new file mode 100644
index 000000000..28d9c562c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top.png
new file mode 100644
index 000000000..7798f53f2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_left.png
new file mode 100644
index 000000000..3de436010
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_right.png
new file mode 100644
index 000000000..49a792131
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_black/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/front.png
new file mode 100644
index 000000000..ca620b513
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_back.png
new file mode 100644
index 000000000..95ed35b23
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_front.png
new file mode 100644
index 000000000..95ed35b23
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_back.png
new file mode 100644
index 000000000..9ca2c142c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_front.png
new file mode 100644
index 000000000..9ca2c142c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/side.png
new file mode 100644
index 000000000..ca620b513
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top.png
new file mode 100644
index 000000000..2232d59d6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_left.png
new file mode 100644
index 000000000..8532610c7
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_right.png
new file mode 100644
index 000000000..e549dc12d
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_blue/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/front.png
new file mode 100644
index 000000000..cce16a3ab
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_back.png
new file mode 100644
index 000000000..91f58317f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_front.png
new file mode 100644
index 000000000..91f58317f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_back.png
new file mode 100644
index 000000000..f28e1e269
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_front.png
new file mode 100644
index 000000000..f28e1e269
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/side.png
new file mode 100644
index 000000000..cce16a3ab
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top.png
new file mode 100644
index 000000000..4ece6cfcf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_left.png
new file mode 100644
index 000000000..735d4b841
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_right.png
new file mode 100644
index 000000000..c0699deaf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_brown/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/front.png
new file mode 100644
index 000000000..06e5d0b74
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_back.png
new file mode 100644
index 000000000..003384b0c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_front.png
new file mode 100644
index 000000000..003384b0c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_back.png
new file mode 100644
index 000000000..08d7a96ed
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_front.png
new file mode 100644
index 000000000..08d7a96ed
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/side.png
new file mode 100644
index 000000000..06e5d0b74
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top.png
new file mode 100644
index 000000000..451bf603e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_left.png
new file mode 100644
index 000000000..76506953c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_right.png
new file mode 100644
index 000000000..54119ce84
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_cyan/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/front.png
new file mode 100644
index 000000000..4aa0f9081
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_back.png
new file mode 100644
index 000000000..5a86a9fd2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_front.png
new file mode 100644
index 000000000..5a86a9fd2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_back.png
new file mode 100644
index 000000000..0508a7c67
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_front.png
new file mode 100644
index 000000000..0508a7c67
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/side.png
new file mode 100644
index 000000000..4aa0f9081
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top.png
new file mode 100644
index 000000000..12cc29787
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_left.png
new file mode 100644
index 000000000..74fdff760
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_right.png
new file mode 100644
index 000000000..2b032417e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_gray/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/front.png
new file mode 100644
index 000000000..729c9f6ee
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_back.png
new file mode 100644
index 000000000..03a84b41f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_front.png
new file mode 100644
index 000000000..03a84b41f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_top.png
new file mode 100644
index 000000000..d034d26f9
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/left_top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_back.png
new file mode 100644
index 000000000..3b39ef6cf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_front.png
new file mode 100644
index 000000000..3b39ef6cf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_top.png
new file mode 100644
index 000000000..3ac1c1603
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/right_top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/side.png
new file mode 100644
index 000000000..729c9f6ee
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top.png
new file mode 100644
index 000000000..6978d69d6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_left.png
new file mode 100644
index 000000000..e9f80d082
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_right.png
new file mode 100644
index 000000000..e7a78eb1c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_green/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/front.png
new file mode 100644
index 000000000..8b29beddb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png
new file mode 100644
index 000000000..6f032747e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png
new file mode 100644
index 000000000..6f032747e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png
new file mode 100644
index 000000000..2f0637883
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png
new file mode 100644
index 000000000..2f0637883
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/side.png
new file mode 100644
index 000000000..8b29beddb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top.png
new file mode 100644
index 000000000..6e3b46f76
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png
new file mode 100644
index 000000000..ba783c5f5
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png
new file mode 100644
index 000000000..94e8bd365
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lightblue/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/front.png
new file mode 100644
index 000000000..e8b3b340c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_back.png
new file mode 100644
index 000000000..477a152d2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_front.png
new file mode 100644
index 000000000..477a152d2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_back.png
new file mode 100644
index 000000000..9f840da06
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_front.png
new file mode 100644
index 000000000..9f840da06
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/side.png
new file mode 100644
index 000000000..e8b3b340c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top.png
new file mode 100644
index 000000000..4042b11b1
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_left.png
new file mode 100644
index 000000000..e9709f6be
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_right.png
new file mode 100644
index 000000000..d1a9e2468
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_lime/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/front.png
new file mode 100644
index 000000000..67ea448d8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_back.png
new file mode 100644
index 000000000..17b551265
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_front.png
new file mode 100644
index 000000000..17b551265
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_back.png
new file mode 100644
index 000000000..bbed08aa5
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_front.png
new file mode 100644
index 000000000..bbed08aa5
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/side.png
new file mode 100644
index 000000000..67ea448d8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top.png
new file mode 100644
index 000000000..5cc5c8925
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_left.png
new file mode 100644
index 000000000..6042d075c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_right.png
new file mode 100644
index 000000000..be9fc153e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_magenta/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/front.png
new file mode 100644
index 000000000..acfe446a0
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_back.png
new file mode 100644
index 000000000..6229b7303
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_front.png
new file mode 100644
index 000000000..6229b7303
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_back.png
new file mode 100644
index 000000000..629add78b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_front.png
new file mode 100644
index 000000000..629add78b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/side.png
new file mode 100644
index 000000000..acfe446a0
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top.png
new file mode 100644
index 000000000..066107dbb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_left.png
new file mode 100644
index 000000000..bab8b2916
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_right.png
new file mode 100644
index 000000000..591c2428b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_orange/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/front.png
new file mode 100644
index 000000000..ff2c6a68d
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_back.png
new file mode 100644
index 000000000..d1e771c72
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_front.png
new file mode 100644
index 000000000..d1e771c72
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_back.png
new file mode 100644
index 000000000..0cc7e0f2f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_front.png
new file mode 100644
index 000000000..0cc7e0f2f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/side.png
new file mode 100644
index 000000000..ff2c6a68d
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top.png
new file mode 100644
index 000000000..5e1dd7592
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_left.png
new file mode 100644
index 000000000..9474959e6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_right.png
new file mode 100644
index 000000000..3c8927ecc
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_pink/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/front.png
new file mode 100644
index 000000000..2eb2a9cac
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_back.png
new file mode 100644
index 000000000..44bfff413
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_front.png
new file mode 100644
index 000000000..44bfff413
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_back.png
new file mode 100644
index 000000000..f0e778b54
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_front.png
new file mode 100644
index 000000000..f0e778b54
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/side.png
new file mode 100644
index 000000000..2eb2a9cac
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top.png
new file mode 100644
index 000000000..31b76d203
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_left.png
new file mode 100644
index 000000000..9c5e95896
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_right.png
new file mode 100644
index 000000000..e6d2208c8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_purple/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/front.png
new file mode 100644
index 000000000..e92f18ce8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_back.png
new file mode 100644
index 000000000..3c8c63a85
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_front.png
new file mode 100644
index 000000000..3c8c63a85
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_back.png
new file mode 100644
index 000000000..40dbdf6fd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_front.png
new file mode 100644
index 000000000..40dbdf6fd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/side.png
new file mode 100644
index 000000000..e92f18ce8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top.png
new file mode 100644
index 000000000..db1aad989
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_left.png
new file mode 100644
index 000000000..65e5f80ff
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_right.png
new file mode 100644
index 000000000..b302f216c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_red/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/front.png
new file mode 100644
index 000000000..0547740d8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_back.png
new file mode 100644
index 000000000..d12806430
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_front.png
new file mode 100644
index 000000000..d12806430
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_back.png
new file mode 100644
index 000000000..98fa55f02
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_front.png
new file mode 100644
index 000000000..98fa55f02
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/side.png
new file mode 100644
index 000000000..0547740d8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top.png
new file mode 100644
index 000000000..4a9838d46
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_left.png
new file mode 100644
index 000000000..52f504735
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_right.png
new file mode 100644
index 000000000..99a18d5fc
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_silver/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/front.png
new file mode 100644
index 000000000..5188c1476
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_back.png
new file mode 100644
index 000000000..a8527317c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_front.png
new file mode 100644
index 000000000..a8527317c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_back.png
new file mode 100644
index 000000000..3a8b46cd4
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_front.png
new file mode 100644
index 000000000..3a8b46cd4
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/side.png
new file mode 100644
index 000000000..5188c1476
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top.png
new file mode 100644
index 000000000..4d8d7a5f2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_left.png
new file mode 100644
index 000000000..06b1ffbf6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_right.png
new file mode 100644
index 000000000..be006c41c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_white/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/front.png
new file mode 100644
index 000000000..49cf547c6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_back.png
new file mode 100644
index 000000000..da6ec51de
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_front.png
new file mode 100644
index 000000000..da6ec51de
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/left_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_back.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_back.png
new file mode 100644
index 000000000..fc006a8f1
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_back.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_front.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_front.png
new file mode 100644
index 000000000..fc006a8f1
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/right_front.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/side.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/side.png
new file mode 100644
index 000000000..49cf547c6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/side.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top.png
new file mode 100644
index 000000000..94adfc8a0
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_left.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_left.png
new file mode 100644
index 000000000..e60582f4f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_left.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_right.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_right.png
new file mode 100644
index 000000000..ae05b18ab
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/chest/planks_yellow/top_right.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/bottom.png
new file mode 100644
index 000000000..7f7bddd1a
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/top.png
new file mode 100644
index 000000000..2c70670bd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/bottom.png
new file mode 100644
index 000000000..8dc309232
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/top.png
new file mode 100644
index 000000000..ac0c39b89
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_black/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/bottom.png
new file mode 100644
index 000000000..da616d9c2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/top.png
new file mode 100644
index 000000000..e2ca72e1c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_blue/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/bottom.png
new file mode 100644
index 000000000..7802c6e26
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/top.png
new file mode 100644
index 000000000..62e77a4bf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_brown/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/bottom.png
new file mode 100644
index 000000000..1bc653d57
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/top.png
new file mode 100644
index 000000000..805580d72
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_cyan/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/bottom.png
new file mode 100644
index 000000000..6570a935f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/top.png
new file mode 100644
index 000000000..11eea573b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_gray/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/bottom.png
new file mode 100644
index 000000000..112dec60b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/top.png
new file mode 100644
index 000000000..da578ba78
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_green/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/bottom.png
new file mode 100644
index 000000000..07f4f6264
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/top.png
new file mode 100644
index 000000000..98e3aa5f1
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lightblue/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/bottom.png
new file mode 100644
index 000000000..36a5fef7a
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/top.png
new file mode 100644
index 000000000..d0c5ff17a
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_lime/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/bottom.png
new file mode 100644
index 000000000..778e98e7e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/top.png
new file mode 100644
index 000000000..42561514a
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_magenta/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/bottom.png
new file mode 100644
index 000000000..580fe42ad
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/top.png
new file mode 100644
index 000000000..bd77c14a0
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_orange/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/bottom.png
new file mode 100644
index 000000000..614b83ad8
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/top.png
new file mode 100644
index 000000000..b0746cf03
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_pink/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/bottom.png
new file mode 100644
index 000000000..b731e1084
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/top.png
new file mode 100644
index 000000000..4b0a56586
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_purple/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/bottom.png
new file mode 100644
index 000000000..43d13dafb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/top.png
new file mode 100644
index 000000000..3f112403e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_red/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/bottom.png
new file mode 100644
index 000000000..71d4a967e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/top.png
new file mode 100644
index 000000000..89336f0c4
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_silver/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/bottom.png
new file mode 100644
index 000000000..19b2293d6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/top.png
new file mode 100644
index 000000000..c37b20729
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_white/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/bottom.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/bottom.png
new file mode 100644
index 000000000..772e0906f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/bottom.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/top.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/top.png
new file mode 100644
index 000000000..db245a1af
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/door/planks_yellow/top.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/torch_coal.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/torch_coal.png
new file mode 100644
index 000000000..9ba4a1cf9
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/block/torch_coal.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/char/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/char/0.png
new file mode 100644
index 000000000..93ecfb3dd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/char/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/0.png
new file mode 100644
index 000000000..edb00b16b
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/1.png
new file mode 100644
index 000000000..97228fc13
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/2.png
new file mode 100644
index 000000000..be493d3e0
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/3.png
new file mode 100644
index 000000000..9faf56f18
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/variants.json
new file mode 100644
index 000000000..42eaed298
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/chicken/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 4
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/0.png
new file mode 100644
index 000000000..d85feb839
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/1.png
new file mode 100644
index 000000000..74a225340
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/2.png
new file mode 100644
index 000000000..f1c1f85bb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/3.png
new file mode 100644
index 000000000..54ad5ff95
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/variants.json
new file mode 100644
index 000000000..42eaed298
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/cow/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 4
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/creeper/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/creeper/0.png
new file mode 100644
index 000000000..5bb06e30c
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/creeper/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/0.png
new file mode 100644
index 000000000..b7c769425
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/1.png
new file mode 100644
index 000000000..697e88451
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/2.png
new file mode 100644
index 000000000..39f8b6c19
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/3.png
new file mode 100644
index 000000000..5d755c78f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/4.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/4.png
new file mode 100644
index 000000000..5144a2e39
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/4.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/variants.json
new file mode 100644
index 000000000..5bf0f12e2
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/skeleton/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 5
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/0.png
new file mode 100644
index 000000000..08344a837
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/1.png
new file mode 100644
index 000000000..9a9748993
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/2.png
new file mode 100644
index 000000000..f8df6e908
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/3.png
new file mode 100644
index 000000000..84ae2bf09
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/0.png
new file mode 100644
index 000000000..2a7734f93
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/1.png
new file mode 100644
index 000000000..45cd1daa3
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/2.png
new file mode 100644
index 000000000..e5687ff05
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/3.png
new file mode 100644
index 000000000..43145a612
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/eyes/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/variants.json
new file mode 100644
index 000000000..42eaed298
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/spider/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 4
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/0.png
new file mode 100644
index 000000000..4b24458fd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/1.png
new file mode 100644
index 000000000..4b24458fd
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/variants.json
new file mode 100644
index 000000000..e610d1df0
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 2
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/0.png
new file mode 100644
index 000000000..9e3cb61fc
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/1.png
new file mode 100644
index 000000000..4bb3e27c3
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/variants.json
new file mode 100644
index 000000000..e610d1df0
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/wolf_tame/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 2
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/0.png
new file mode 100644
index 000000000..9018970f2
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/1.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/1.png
new file mode 100644
index 000000000..47a9d68f4
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/1.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/10.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/10.png
new file mode 100644
index 000000000..e2f68fa03
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/10.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/11.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/11.png
new file mode 100644
index 000000000..7a9b9fe9d
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/11.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/12.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/12.png
new file mode 100644
index 000000000..99677309f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/12.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/13.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/13.png
new file mode 100644
index 000000000..06fdae19e
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/13.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/14.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/14.png
new file mode 100644
index 000000000..0c5210713
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/14.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/15.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/15.png
new file mode 100644
index 000000000..183275f78
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/15.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/2.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/2.png
new file mode 100644
index 000000000..8b800470f
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/2.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/3.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/3.png
new file mode 100644
index 000000000..b27ada224
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/3.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/4.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/4.png
new file mode 100644
index 000000000..fc58b8475
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/4.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/5.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/5.png
new file mode 100644
index 000000000..5b48266a6
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/5.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/6.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/6.png
new file mode 100644
index 000000000..b36994011
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/6.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/7.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/7.png
new file mode 100644
index 000000000..afefd408a
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/7.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/8.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/8.png
new file mode 100644
index 000000000..e7cf50792
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/8.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/9.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/9.png
new file mode 100644
index 000000000..fcf0a55bf
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/9.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/variants.json b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/variants.json
new file mode 100644
index 000000000..089ca2f7d
--- /dev/null
+++ b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie/variants.json
@@ -0,0 +1,3 @@
+{
+    "skins": 16
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie_armored/0.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie_armored/0.png
new file mode 100644
index 000000000..86c4f64fb
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/entity/zombie_armored/0.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/majonk.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/majonk.png
new file mode 100644
index 000000000..e97630d60
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/majonk.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mclogo.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mclogo.png
new file mode 100644
index 000000000..504449b72
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mclogo.png differ
diff --git a/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mojang.png b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mojang.png
new file mode 100644
index 000000000..dad859287
Binary files /dev/null and b/game/client/src/main/resources/holidays/xmas/assets/minecraft/textures/gui/title/mojang.png differ
diff --git a/game/core/src/main/resources/lang/en_US/options.lang b/game/core/src/main/resources/lang/en_US/options.lang
index f486cd42a..29b517472 100644
--- a/game/core/src/main/resources/lang/en_US/options.lang
+++ b/game/core/src/main/resources/lang/en_US/options.lang
@@ -170,6 +170,7 @@ options.chatVisibility=Chat Visibility
 options.chatVisibility.show_all=Always Show
 options.chatVisibility.show_when_chatting=Only Show When Chatting
 options.chatVisibility.never_show=Never Show
+options.enableHolidayTextures=Enable Holiday Textures
 
 options.tooltipStyle.default=Default
 options.tooltipStyle.modern=Modern
